diff -pruN 4.6.2-1/cinnamon-session/csm-consolekit.c 4.8.0-2/cinnamon-session/csm-consolekit.c
--- 4.6.2-1/cinnamon-session/csm-consolekit.c	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/cinnamon-session/csm-consolekit.c	2020-11-25 14:20:12.000000000 +0000
@@ -713,7 +713,7 @@ hibernate_done (GObject      *source,
 }
 
 static void
-csm_consolekit_suspend (CsmSystem *system)
+csm_consolekit_suspend (CsmSystem *system, gboolean suspend_then_hibernate)
 {
 #ifdef HAVE_OLD_UPOWER
         CsmConsolekit *consolekit = CSM_CONSOLEKIT (system);
@@ -728,8 +728,14 @@ csm_consolekit_suspend (CsmSystem *syste
 #else
         CsmConsolekit *manager = CSM_CONSOLEKIT (system);
 
+	gchar *method = "Suspend";
+	if (suspend_then_hibernate && csm_consolekit_can_suspend (system) && csm_consolekit_can_hibernate (system)) {
+		method = "SuspendThenHibernate";
+	}
+	g_debug ("Suspend using: %s", method);
+
         g_dbus_proxy_call (manager->priv->ck_proxy,
-                           "Suspend",
+                           method,
                            g_variant_new ("(b)", TRUE),
                            0,
                            G_MAXINT,
diff -pruN 4.6.2-1/cinnamon-session/csm-manager.c 4.8.0-2/cinnamon-session/csm-manager.c
--- 4.6.2-1/cinnamon-session/csm-manager.c	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/cinnamon-session/csm-manager.c	2020-11-25 14:20:12.000000000 +0000
@@ -93,6 +93,7 @@
 #define KEY_SHOW_FALLBACK_WARNING "show-fallback-warning"
 #define KEY_BLACKLIST             "autostart-blacklist"
 #define KEY_PREFER_HYBRID_SLEEP   "prefer-hybrid-sleep"
+#define KEY_SUSPEND_HIBERNATE     "suspend-then-hibernate"
 
 #define POWER_SETTINGS_SCHEMA     "org.cinnamon.settings-daemon.plugins.power"
 #define KEY_LOCK_ON_SUSPEND       "lock-on-suspend"
@@ -1287,7 +1288,7 @@ manager_attempt_suspend (CsmManager *man
             csm_system_can_hybrid_sleep (manager->priv->system)) {
                 csm_system_hybrid_sleep (manager->priv->system);
         } else if (csm_system_can_suspend (manager->priv->system)) {
-                csm_system_suspend (manager->priv->system);
+                csm_system_suspend (manager->priv->system, g_settings_get_boolean (manager->priv->settings, KEY_SUSPEND_HIBERNATE));
         }
 }
 
diff -pruN 4.6.2-1/cinnamon-session/csm-system.c 4.8.0-2/cinnamon-session/csm-system.c
--- 4.6.2-1/cinnamon-session/csm-system.c	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/cinnamon-session/csm-system.c	2020-11-25 14:20:12.000000000 +0000
@@ -119,9 +119,9 @@ csm_system_hybrid_sleep (CsmSystem *syst
 }
 
 void
-csm_system_suspend (CsmSystem *system)
+csm_system_suspend (CsmSystem *system, gboolean suspend_then_hibernate)
 {
-        CSM_SYSTEM_GET_IFACE (system)->suspend (system);
+        CSM_SYSTEM_GET_IFACE (system)->suspend (system, suspend_then_hibernate);
 }
 
 void
diff -pruN 4.6.2-1/cinnamon-session/csm-systemd.c 4.8.0-2/cinnamon-session/csm-systemd.c
--- 4.6.2-1/cinnamon-session/csm-systemd.c	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/cinnamon-session/csm-systemd.c	2020-11-25 14:20:12.000000000 +0000
@@ -542,12 +542,18 @@ csm_systemd_hybrid_sleep (CsmSystem *sys
 }
 
 static void
-csm_systemd_suspend (CsmSystem *system)
+csm_systemd_suspend (CsmSystem *system, gboolean suspend_then_hibernate)
 {
+	gchar *method = "Suspend";
+	if (suspend_then_hibernate && csm_systemd_can_suspend (system) && csm_systemd_can_hibernate (system)) {
+		method = "SuspendThenHibernate";
+	}
+	g_debug ("Suspend using: %s", method);
+
         CsmSystemd *manager = CSM_SYSTEMD (system);
 
         g_dbus_proxy_call (manager->priv->sd_proxy,
-                           "Suspend",
+                           method,
                            g_variant_new ("(b)", TRUE),
                            0,
                            G_MAXINT,
diff -pruN 4.6.2-1/cinnamon-session/csm-system.h 4.8.0-2/cinnamon-session/csm-system.h
--- 4.6.2-1/cinnamon-session/csm-system.h	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/cinnamon-session/csm-system.h	2020-11-25 14:20:12.000000000 +0000
@@ -58,7 +58,8 @@ struct _CsmSystemInterface
         void     (* attempt_stop)     (CsmSystem *system);
         void     (* attempt_restart)  (CsmSystem *system);
         void     (* hybrid_sleep)     (CsmSystem *system);
-        void     (* suspend)          (CsmSystem *system);
+        void     (* suspend)          (CsmSystem *system,
+				       gboolean suspend_then_hibernate);
         void     (* hibernate)        (CsmSystem *system);
         void     (* set_session_idle) (CsmSystem *system,
                                        gboolean   is_idle);
@@ -100,7 +101,8 @@ void       csm_system_attempt_restart  (
 
 void       csm_system_hybrid_sleep     (CsmSystem *system);
 
-void       csm_system_suspend          (CsmSystem *system);
+void       csm_system_suspend          (CsmSystem *system,
+					gboolean suspend_then_hibernate);
 
 void       csm_system_hibernate        (CsmSystem *system);
 
diff -pruN 4.6.2-1/data/org.cinnamon.SessionManager.gschema.xml 4.8.0-2/data/org.cinnamon.SessionManager.gschema.xml
--- 4.6.2-1/data/org.cinnamon.SessionManager.gschema.xml	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/data/org.cinnamon.SessionManager.gschema.xml	2020-11-25 14:20:12.000000000 +0000
@@ -48,5 +48,10 @@
       <summary>If your hardware and login service supports 'Hybrid Sleep' then use it instead of normal Suspend</summary>
       <description>Whether or not to attempt to use hybrid sleep mode for suspend.  If it is unsupported, normal sleep will be used instead</description>
     </key>
+    <key name="suspend-then-hibernate" type="b">
+      <default>false</default>
+      <summary>The system is suspended and put into hibernation after being suspended for a certain time. (Defaults to 2h, see systemd-sleep.conf)</summary>
+      <description>Whether or not to attempt to use suspend-then-hibernate. If it is unsupported, normal suspend will be used instead</description>
+    </key>
   </schema>
 </schemalist>
diff -pruN 4.6.2-1/debian/changelog 4.8.0-2/debian/changelog
--- 4.6.2-1/debian/changelog	2020-08-14 05:48:37.000000000 +0000
+++ 4.8.0-2/debian/changelog	2020-12-16 03:37:59.000000000 +0000
@@ -1,3 +1,17 @@
+cinnamon-session (4.8.0-2) unstable; urgency=medium
+
+  * Release to unstable.
+
+ -- Norbert Preining <norbert@preining.info>  Wed, 16 Dec 2020 12:37:59 +0900
+
+cinnamon-session (4.8.0-1) experimental; urgency=medium
+
+  * New upstream version 4.8.0
+  * update patch
+  * Bump inter-cinnamon deps to 4.8
+
+ -- Norbert Preining <norbert@preining.info>  Tue, 01 Dec 2020 08:37:07 +0900
+
 cinnamon-session (4.6.2-1) unstable; urgency=medium
 
   * New upstream version 4.6.2
diff -pruN 4.6.2-1/debian/control 4.8.0-2/debian/control
--- 4.6.2-1/debian/control	2020-08-14 05:48:37.000000000 +0000
+++ 4.8.0-2/debian/control	2020-12-16 03:37:59.000000000 +0000
@@ -8,7 +8,7 @@ Uploaders:
  Fabio Fantoni <fantonifabio@tiscali.it>,
  Norbert Preining <norbert@preining.info>
 Build-Depends:
- debhelper-compat (= 11),
+ debhelper-compat (= 13),
  gnome-pkg-tools (>= 0.13),
  intltool (>= 0.40.6),
  libcanberra-dev,
@@ -40,16 +40,16 @@ Vcs-Git: https://salsa.debian.org/cinnam
 Package: cinnamon-session
 Architecture: any
 Depends:
- cinnamon-desktop-data (>= 4.6),
+ cinnamon-desktop-data (>= 4.8),
  cinnamon-session-common (= ${source:Version}),
  default-dbus-session-bus | dbus-session-bus,
  upower (>= 0.9.0),
  ${misc:Depends},
  ${shlibs:Depends},
-Recommends: cinnamon-l10n (>= 4.6)
+Recommends: cinnamon-l10n (>= 4.8)
 Breaks:
- cinnamon (<< 4.6~),
- cinnamon-core (<< 4.6~),
+ cinnamon (<< 4.8~),
+ cinnamon-core (<< 4.8~),
  cinnamon-session-common (<< 2.2.2-5~),
 Replaces: cinnamon-session-common (<< 2.2.2-5~)
 Provides: x-session-manager
diff -pruN 4.6.2-1/debian/patches/Comment-GDBusConnection-method-call-with-a-DbusGConnectio.patch 4.8.0-2/debian/patches/Comment-GDBusConnection-method-call-with-a-DbusGConnectio.patch
--- 4.6.2-1/debian/patches/Comment-GDBusConnection-method-call-with-a-DbusGConnectio.patch	2020-08-14 05:48:37.000000000 +0000
+++ 4.8.0-2/debian/patches/Comment-GDBusConnection-method-call-with-a-DbusGConnectio.patch	2020-12-16 03:37:59.000000000 +0000
@@ -7,9 +7,9 @@ This was causing that users can't logout
  cinnamon-session/csm-manager.c |    5 +++++
  1 file changed, 5 insertions(+)
 
---- cinnamon-session.git.orig/cinnamon-session/csm-manager.c
-+++ cinnamon-session.git/cinnamon-session/csm-manager.c
-@@ -952,6 +952,10 @@ maybe_restart_user_bus (CsmManager *mana
+--- a/cinnamon-session/csm-manager.c
++++ b/cinnamon-session/csm-manager.c
+@@ -953,6 +953,10 @@ maybe_restart_user_bus (CsmManager *mana
  
          g_debug ("CsmManager: restarting user bus");
  
@@ -20,7 +20,7 @@ This was causing that users can't logout
          reply = g_dbus_connection_call_sync (manager->priv->connection,
                                               "org.freedesktop.systemd1",
                                               "/org/freedesktop/systemd1",
-@@ -963,6 +967,7 @@ maybe_restart_user_bus (CsmManager *mana
+@@ -964,6 +968,7 @@ maybe_restart_user_bus (CsmManager *mana
                                               -1,
                                               NULL,
                                               &error);
diff -pruN 4.6.2-1/debian/rules 4.8.0-2/debian/rules
--- 4.6.2-1/debian/rules	2020-08-14 05:48:37.000000000 +0000
+++ 4.8.0-2/debian/rules	2020-12-16 03:37:59.000000000 +0000
@@ -15,7 +15,3 @@ override_dh_auto_configure:
 	    -Dxtrans=true \
 	    --libexecdir=/usr/lib/$(DEB_HOST_MULTIARCH)/cinnamon-session
 
-# --list-missing will be default in compat 12
-override_dh_missing:
-	dh_missing --list-missing
-
diff -pruN 4.6.2-1/meson.build 4.8.0-2/meson.build
--- 4.6.2-1/meson.build	2020-08-11 11:40:52.000000000 +0000
+++ 4.8.0-2/meson.build	2020-11-25 14:20:12.000000000 +0000
@@ -1,7 +1,7 @@
 # https://github.com/linuxmint/cinnamon-session
 project('cinnamon-session',
   [ 'c', ],
-  version: '4.6.2',
+  version: '4.8.0',
   meson_version: '>=0.37.0',
 )
 
